(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     15728,        533]
NotebookOptionsPosition[     13352,        443]
NotebookOutlinePosition[     13688,        458]
CellTagsIndexPosition[     13645,        455]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Orthogonal Projection Derivative Filters on the CC Lattice", "Title",
 CellChangeTimes->{{3.4580719796790257`*^9, 3.4580719908347673`*^9}}],

Cell[CellGroupData[{

Cell["Building Block Functions", "Section",
 CellChangeTimes->{{3.458072010573099*^9, 3.458072020221994*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mu", "[", "x_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"x", "<", "0"}], ",", "0", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B", "[", 
   RowBox[{"n_", ",", "x_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "^", "j"}], "/", 
      RowBox[{"(", 
       RowBox[{"Factorial", "[", "n", "]"}], ")"}]}], 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"n", "+", "1"}], ",", "j"}], "]"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        FractionBox[
         RowBox[{"n", "+", "1"}], "2"], "-", "j"}], ")"}], "n"], "*", 
     RowBox[{"mu", "[", 
      RowBox[{"x", "+", 
       FractionBox[
        RowBox[{"n", "+", "1"}], "2"], "-", "j"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"n", "+", "1"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.442946166069409*^9, 3.44294618565029*^9}, {
  3.445362147236102*^9, 3.445362154319851*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bprime", "[", 
    RowBox[{"n_", ",", "x_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"B", "[", 
     RowBox[{
      RowBox[{"n", "-", "1"}], ",", 
      RowBox[{"x", "+", 
       FractionBox["1", "2"]}]}], "]"}], "-", 
    RowBox[{"B", "[", 
     RowBox[{
      RowBox[{"n", "-", "1"}], ",", 
      RowBox[{"x", "-", 
       FractionBox["1", "2"]}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.445362201121688*^9, 3.4453622464962797`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivative Filters", "Section",
 CellChangeTimes->{{3.4580720725599527`*^9, 3.458072076229792*^9}}],

Cell["\<\
The derivative filters only need to be computed in 1 D as the 3 D versions \
can be obtained via a straightforward tensor product with a sampled B-spline \
(given below). Please see Equation (28) in the manuscript for details.\
\>", "Text",
 CellChangeTimes->{{3.458072089826618*^9, 3.458072118872972*^9}, {
   3.45807217734538*^9, 3.458072188654952*^9}, {3.458072285887165*^9, 
   3.4580722946474333`*^9}, {3.4580723935634413`*^9, 3.45807240333989*^9}, 
   3.458072962880973*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "Linear - Linear (",
 StyleBox["ll",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.445362272575913*^9, 3.445362278546605*^9}, {
  3.4580722003962793`*^9, 3.4580722027916517`*^9}}],

Cell["This is given by the derivative of a cubic B - Spline", "Text",
 CellChangeTimes->{{3.445362297649235*^9, 3.445362315664462*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Bprime", "[", 
    RowBox[{"3", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.445362326005129*^9, 3.445362385622033*^9}, {
  3.4453625828133087`*^9, 3.4453626157296658`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", 
   FractionBox["1", "2"], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.4453623860251303`*^9, {3.4453625834223423`*^9, 3.4453626160694838`*^9}, 
   3.458072915298954*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Cubic - Linear (",
 StyleBox["cl",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.445362624985381*^9, 3.445362627618333*^9}, {
  3.4580728443990726`*^9, 3.458072846218604*^9}}],

Cell["This is given by the derivative of a Quintic B - Spline", "Text",
 CellChangeTimes->{{3.445362635764292*^9, 3.445362647310295*^9}, {
  3.4460504636291*^9, 3.446050466836605*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Bprime", "[", 
    RowBox[{"5", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4453626676118526`*^9, 3.445362680843199*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", 
   FractionBox["1", "24"], ",", 
   FractionBox["5", "12"], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox["5", "12"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "24"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.445362682084302*^9, 3.45807291550727*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Cubic - Cubic and Quintic - Linear (",
 StyleBox["cc",
  FontSlant->"Italic"],
 " and ",
 StyleBox["ql",
  FontSlant->"Italic"],
 ")"
}], "Subsubsection",
 CellChangeTimes->{{3.445362702986491*^9, 3.4453627112087812`*^9}, {
  3.445362755713307*^9, 3.445362757583332*^9}, {3.446050523798612*^9, 
  3.4460505257079077`*^9}, {3.4580728505148153`*^9, 3.458072856987033*^9}}],

Cell["These are given by the derivative of a heptic B - Spline", "Text",
 CellChangeTimes->{{3.445362722421425*^9, 3.445362737802595*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Bprime", "[", 
    RowBox[{"7", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.445362760345487*^9, 3.4453627744828043`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   FractionBox["1", "720"], ",", 
   FractionBox["7", "90"], ",", 
   FractionBox["49", "144"], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox["49", "144"]}], ",", 
   RowBox[{"-", 
    FractionBox["7", "90"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "720"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.4453627750763683`*^9, 3.458072915767921*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Quintic - Cubic (",
 StyleBox["qc",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.4453628420305758`*^9, 3.44536284481151*^9}, {
  3.44605054083853*^9, 3.446050542956285*^9}, {3.458072873545516*^9, 
  3.458072875269464*^9}}],

Cell["This is given by the derivative of a Nonic B - Spline", "Text",
 CellChangeTimes->{{3.4453628560469303`*^9, 3.4453628691859922`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Bprime", "[", 
    RowBox[{"9", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.445362886175003*^9, 3.445362898646439*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   FractionBox["1", "40320"], ",", 
   FractionBox["41", "6720"], ",", 
   FractionBox["289", "2880"], ",", 
   FractionBox["809", "2880"], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox["809", "2880"]}], ",", 
   RowBox[{"-", 
    FractionBox["289", "2880"]}], ",", 
   RowBox[{"-", 
    FractionBox["41", "6720"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "40320"]}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.445362900278036*^9, 3.45807291602042*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Autocorrelation Sequences for the Duals", "Section",
 CellChangeTimes->{{3.445363496910935*^9, 3.445363502624991*^9}, {
  3.445363679664956*^9, 3.44536368221416*^9}}],

Cell["\<\
Linear is given by sampling the Cubic B - Spline and Cubic is given by \
sampling the Heptic B - Spline\
\>", "Text",
 CellChangeTimes->{{3.4453635174636707`*^9, 3.445363544431033*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"B", "[", 
    RowBox[{"3", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"B", "[", 
    RowBox[{"7", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.445363563247946*^9, 3.44536357882822*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", 
   FractionBox["1", "6"], ",", 
   FractionBox["2", "3"], ",", 
   FractionBox["1", "6"], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.445363579774932*^9, 3.4580729162555733`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   FractionBox["1", "5040"], ",", 
   FractionBox["1", "42"], ",", 
   FractionBox["397", "1680"], ",", 
   FractionBox["151", "315"], ",", 
   FractionBox["397", "1680"], ",", 
   FractionBox["1", "42"], ",", 
   FractionBox["1", "5040"], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.445363579774932*^9, 3.458072916259585*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sampled Sequences for Pre - Filtering and for Tensor Multiplication\
\>", "Section",
 CellChangeTimes->{{3.4453636856211643`*^9, 3.445363692187725*^9}, {
  3.458072409271233*^9, 3.4580724199010143`*^9}}],

Cell[CellGroupData[{

Cell["Cubic", "Subsection",
 CellChangeTimes->{{3.458072479057062*^9, 3.458072479784327*^9}}],

Cell["\<\
This is the same as the autocorrelation sequence of the linear B - spline.\
\>", "Text",
 CellChangeTimes->{{3.4580726700278387`*^9, 3.458072682739444*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quintic", "Subsection",
 CellChangeTimes->{{3.445363709857209*^9, 3.445363715398448*^9}, {
  3.4453638047053013`*^9, 3.445363809420977*^9}, {3.445374452881213*^9, 
  3.4453744548592854`*^9}, {3.4580727004125137`*^9, 3.45807270779175*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"B", "[", 
    RowBox[{"5", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4453637842802963`*^9, 3.445363795176958*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", 
   FractionBox["1", "120"], ",", 
   FractionBox["13", "60"], ",", 
   FractionBox["11", "20"], ",", 
   FractionBox["13", "60"], ",", 
   FractionBox["1", "120"], ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.445363796425617*^9, 3.458072916294427*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Heptic", "Subsection",
 CellChangeTimes->{{3.4580727596709948`*^9, 3.4580727633341303`*^9}}],

Cell["\<\
This is the same as the autocorrelation sequence of the cubic B - spline.\
\>", "Text",
 CellChangeTimes->{{3.458072774741102*^9, 3.458072786537792*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nonic", "Subsection",
 CellChangeTimes->{{3.445363732445532*^9, 3.445363759591536*^9}, {
  3.458072799535778*^9, 3.4580728001019297`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"B", "[", 
    RowBox[{"9", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.445380366861042*^9, 3.445380375443809*^9}, {
  3.445381429876202*^9, 3.4453814375578547`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   FractionBox["1", "362880"], ",", 
   FractionBox["251", "181440"], ",", 
   FractionBox["913", "22680"], ",", 
   FractionBox["44117", "181440"], ",", 
   FractionBox["15619", "36288"], ",", 
   FractionBox["44117", "181440"], ",", 
   FractionBox["913", "22680"], ",", 
   FractionBox["251", "181440"], ",", 
   FractionBox["1", "362880"], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.445381438047789*^9, 3.458072916314081*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{871, 655},
WindowMargins->{{Automatic, 4}, {Automatic, 27}},
FrontEndVersion->"7.0 for Linux x86 (64-bit) (November 11, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 145, 1, 139, "Title"],
Cell[CellGroupData[{
Cell[737, 27, 109, 1, 72, "Section"],
Cell[849, 30, 1109, 35, 97, "Input"],
Cell[1961, 67, 493, 16, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2491, 88, 105, 1, 72, "Section"],
Cell[2599, 91, 490, 8, 51, "Text"],
Cell[CellGroupData[{
Cell[3114, 103, 219, 7, 37, "Subsection"],
Cell[3336, 112, 135, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[3496, 117, 341, 9, 31, "Input"],
Cell[3840, 128, 461, 11, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4350, 145, 216, 7, 37, "Subsection"],
Cell[4569, 154, 184, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[4778, 160, 290, 8, 31, "Input"],
Cell[5071, 170, 469, 12, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5577, 187, 388, 11, 29, "Subsubsection"],
Cell[5968, 200, 138, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[6131, 205, 290, 8, 31, "Input"],
Cell[6424, 215, 540, 14, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7025, 236, 264, 8, 37, "Subsection"],
Cell[7292, 246, 139, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[7456, 251, 288, 8, 31, "Input"],
Cell[7747, 261, 622, 16, 87, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8430, 284, 172, 2, 72, "Section"],
Cell[8605, 288, 195, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[8825, 296, 505, 16, 52, "Input"],
Cell[9333, 314, 406, 9, 49, "Output"],
Cell[9742, 325, 510, 12, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10301, 343, 213, 4, 72, "Section"],
Cell[CellGroupData[{
Cell[10539, 351, 93, 1, 36, "Subsection"],
Cell[10635, 354, 166, 3, 31, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10838, 362, 244, 3, 36, "Subsection"],
Cell[CellGroupData[{
Cell[11107, 369, 285, 8, 31, "Input"],
Cell[11395, 379, 458, 11, 49, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11902, 396, 98, 1, 36, "Subsection"],
Cell[12003, 399, 163, 3, 31, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12203, 407, 144, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[12372, 413, 334, 9, 31, "Input"],
Cell[12709, 424, 591, 13, 87, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
